MountedFatfs

Struct MountedFatfs 

pub struct MountedFatfs<'a, T> { /* private fields */ }
Represents a mounted FAT filesystem instance that can be used to interact with the filesystem. The filesystem is automatically unmounted when the instance is dropped.

The interaction happens via the native, unsafe FATFS library API (i.e. crate::sys::f_open, crate::sys::f_read and so on). An alternative way to mount the filesystem is to use the VFS API, which is more high-level and abstracts the underlying filesystem.

Implementations

Source

impl<T> MountedFatfs<'_, T>

pub fn fatfs(&self) -> &FATFS

Get the underlying FATFS instance.